# Generated by roxygen2: do not edit by hand

S3method(format,tide_harmonics)
S3method(print,tide_harmonics)
S3method(subset,tide_harmonics)
export(is.tide_harmonics)
export(tide_datetimes)
export(tide_height)
export(tide_height_data)
export(tide_slack_data)
export(tide_stations)
import(chk)
import(dttr2)
